@@ -6,16 +6,13 @@
 #
 #=======================================================================
 
-import string
 import sys
-from sys import maxint
-from types import TupleType
 
 from Transitions import TransitionMap
 
 LOWEST_PRIORITY = -sys.maxint
 
-class Machine:
+class Machine(object):
   """A collection of Nodes representing an NFA or DFA."""
   states = None         # [Node]
   next_state_number = 1
@@ -54,12 +51,12 @@ class Machine:
     file.write("Plex.Machine:\n")
     if self.initial_states is not None:
       file.write("   Initial states:\n")
-      for (name, state) in self.initial_states.items():
+      for (name, state) in self.initial_states.iteritems():
         file.write("      '%s': %d\n" % (name, state.number))
     for s in self.states:
       s.dump(file)
 
-class Node:
+class Node(object):
   """A state of an NFA or DFA."""
   transitions = None       # TransitionMap
   action = None            # Action
@@ -101,13 +98,6 @@ class Node:
   def get_action_priority(self):
     return self.action_priority
 
-#    def merge_actions(self, other_state):
-#        """Merge actions of other state into this state according
-#    to their priorities."""
-#        action = other_state.get_action()
-#        priority = other_state.get_action_priority()
-#        self.set_action(action, priority)
-
   def is_accepting(self):
     return self.action is not None
 
@@ -115,7 +105,6 @@ class Node:
     return "State %d" % self.number
 
   def dump(self, file):
-    import string
     # Header
     file.write("   State %d:\n" % self.number)
     # Transitions
@@ -126,9 +115,11 @@ class Node:
     priority = self.action_priority
     if action is not None:
       file.write("      %s [priority %d]\n" % (action, priority))
-  
 
-class FastMachine:
+  def __lt__(self, other):
+    return self.number < other.number
+
+class FastMachine(object):
   """
   FastMachine is a deterministic machine represented in a way that
   allows fast scanning.
@@ -150,11 +141,11 @@ class FastMachine:
       for old_state in old_machine.states:
         new_state = self.new_state()
         old_to_new[old_state] = new_state
-      for name, old_state in old_machine.initial_states.items():
+      for name, old_state in old_machine.initial_states.iteritems():
         initial_states[name] = old_to_new[old_state]
       for old_state in old_machine.states:
         new_state = old_to_new[old_state]
-        for event, old_state_set in old_state.transitions.items():
+        for event, old_state_set in old_state.transitions.iteritems():
           if old_state_set:
             new_state[event] = old_to_new[old_state_set.keys()[0]]
           else:
@@ -177,8 +168,8 @@ class FastMachine:
   def make_initial_state(self, name, state):
     self.initial_states[name] = state
   
-  def add_transitions(self, state, event, new_state):
-    if type(event) == TupleType:
+  def add_transitions(self, state, event, new_state, maxint=sys.maxint):
+    if type(event) is tuple:
       code0, code1 = event
       if code0 == -maxint:
         state['else'] = new_state
@@ -195,13 +186,12 @@ class FastMachine:
   def dump(self, file):
     file.write("Plex.FastMachine:\n")
     file.write("   Initial states:\n")
-    for name, state in self.initial_states.items():
+    for name, state in self.initial_states.iteritems():
       file.write("      %s: %s\n" % (repr(name), state['number']))
     for state in self.states:
       self.dump_state(state, file)
 
   def dump_state(self, state, file):
-    import string
     # Header
     file.write("   State %d:\n" % state['number'])
     # Transitions
@@ -214,7 +204,7 @@ class FastMachine:
   def dump_transitions(self, state, file):
     chars_leading_to_state = {}
     special_to_state = {}
-    for (c, s) in state.items():
+    for (c, s) in state.iteritems():
       if len(c) == 1:
         chars = chars_leading_to_state.get(id(s), None)
         if chars is None:
@@ -256,7 +246,7 @@ class FastMachine:
     return tuple(result)
   
   def ranges_to_string(self, range_list):
-    return string.join(map(self.range_to_string, range_list), ",")
+    return ','.join(map(self.range_to_string, range_list))
   
   def range_to_string(self, range_tuple):
     (c1, c2) = range_tuple
@@ -264,64 +254,3 @@ class FastMachine:
       return repr(c1)
     else:
       return "%s..%s" % (repr(c1), repr(c2))
-##
-## (Superseded by Machines.FastMachine)
-##
-## class StateTableMachine:
-##   """
-##   StateTableMachine is an alternative representation of a Machine
-##   that can be run more efficiently.
-##   """
-##   initial_states = None # {state_name:state_index}
-##   states = None # [([state] indexed by char code, Action)] 
-  
-##   special_map = {'bol':256, 'eol':257, 'eof':258}
-  
-##   def __init__(self, m):
-##     """
-##     Initialise StateTableMachine from Machine |m|.
-##     """
-##     initial_states = self.initial_states = {}
-##     states = self.states = [None]
-##     old_to_new = {}
-##     i = 1
-##     for old_state in m.states:
-##       new_state = ([0] * 259, old_state.get_action())
-##       states.append(new_state)
-##       old_to_new[old_state] = i # new_state
-##       i = i + 1
-##     for name, old_state in m.initial_states.items():
-##       initial_states[name] = old_to_new[old_state]
-##     for old_state in m.states:
-##       new_state_index = old_to_new[old_state]
-##       new_table = states[new_state_index][0]
-##       transitions = old_state.transitions
-##       for c, old_targets in transitions.items():
-##         if old_targets:
-##           old_target = old_targets[0]
-##           new_target_index = old_to_new[old_target]
-##           if len(c) == 1:
-##             a = ord(c)
-##           else:
-##             a = self.special_map[c]
-##           new_table[a] = states[new_target_index]
-
-##   def dump(self, f):
-##     f.write("Plex.StateTableMachine:\n")
-##     f.write("    Initial states:\n")
-##     for name, index in self.initial_states.items():
-##       f.write("        %s: State %d\n" % (
-##         repr(name), id(self.states[index])))
-##     for i in xrange(1, len(self.states)):
-##       table, action = self.states[i]
-##       f.write("    State %d:" % i)
-##       if action:
-##         f.write("%s" % action)
-##       f.write("\n")
-##       f.write("        %s\n" % map(id,table))
-      
-      
-      
-      
-
-
